==> cxf-testutils-2.0.6.3-fuse-sources.jar: org/apache/schema_validation/types/OccuringStruct.java <==

package org.apache.schema_validation.types;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for OccuringStruct complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OccuringStruct">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence maxOccurs="5">
 *         &lt;element name="varFloat" type="{http://www.w3.org/2001/XMLSchema}float"/>
 *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int" minOccurs="0"/>
 *         &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OccuringStruct", propOrder = {
    "varFloatAndVarIntAndVarString"
})
public class OccuringStruct {

    @XmlElements({
        @XmlElement(name = "varFloat", namespace = "http://apache.org/schema_validation/types", required = true, type = Float.class),
        @XmlElement(name = "varString", namespace = "http://apache.org/schema_validation/types", required = true, type = String.class),
        @XmlElement(name = "varInt", namespace = "http://apache.org/schema_validation/types", required = true, type = Integer.class)
    })
    protected List<Serializable> varFloatAndVarIntAndVarString;

    /**
     * Gets the value of the varFloatAndVarIntAndVarString property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the varFloatAndVarIntAndVarString property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVarFloatAndVarIntAndVarString().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Float }
     * {@link String }
     * {@link Integer }
     * 
     * 
     */
    public List<Serializable> getVarFloatAndVarIntAndVarString() {
        if (varFloatAndVarIntAndVarString == null) {
            varFloatAndVarIntAndVarString = new ArrayList<Serializable>();
        }
        return this.varFloatAndVarIntAndVarString;
    }

}

==> cxf-testutils-2.0.6.10-fuse-sources.jar: org/apache/schema_validation/types/OccuringStruct.java <==

package org.apache.schema_validation.types;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for OccuringStruct complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OccuringStruct">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence maxOccurs="5">
 *         &lt;element name="varFloat" type="{http://www.w3.org/2001/XMLSchema}float"/>
 *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int" minOccurs="0"/>
 *         &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OccuringStruct", propOrder = {
    "varFloatAndVarIntAndVarString"
})
public class OccuringStruct {

    @XmlElements({
        @XmlElement(name = "varFloat", namespace = "http://apache.org/schema_validation/types", required = true, type = Float.class),
        @XmlElement(name = "varInt", namespace = "http://apache.org/schema_validation/types", required = true, type = Integer.class),
        @XmlElement(name = "varString", namespace = "http://apache.org/schema_validation/types", required = true, type = String.class)
    })
    protected List<Serializable> varFloatAndVarIntAndVarString;

    /**
     * Gets the value of the varFloatAndVarIntAndVarString property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the varFloatAndVarIntAndVarString property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVarFloatAndVarIntAndVarString().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Float }
     * {@link Integer }
     * {@link String }
     * 
     * 
     */
    public List<Serializable> getVarFloatAndVarIntAndVarString() {
        if (varFloatAndVarIntAndVarString == null) {
            varFloatAndVarIntAndVarString = new ArrayList<Serializable>();
        }
        return this.varFloatAndVarIntAndVarString;
    }

}
